@@ -2,6 +2,10 @@ use tokio::sync::mpsc;
 use tokio::sync::oneshot;
 use tower_service::Service;
 
+/// non-Send support.
+/// `#[service(?Send)]` generates non-Send futures.
+pub mod no_send;
+
 // Re-exported for compiler
 pub use async_trait::async_trait;
 pub use futures::future::poll_fn;
